Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(78)

Unified Diff: components/mus/gpu/gpu_service_mus.h

Issue 2087583002: Remove calls to MessageLoop::current() in components. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: fix test error Created 4 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « components/mus/common/gpu_service.cc ('k') | components/mus/gpu/gpu_service_mus.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: components/mus/gpu/gpu_service_mus.h
diff --git a/components/mus/gpu/gpu_service_mus.h b/components/mus/gpu/gpu_service_mus.h
index a371bdf4da50fa9f8236cb8e4202f290529a9275..b6bfd1b69f59036f845de51d5b5968cd72e7c164 100644
--- a/components/mus/gpu/gpu_service_mus.h
+++ b/components/mus/gpu/gpu_service_mus.h
@@ -134,8 +134,8 @@ class GpuServiceMus : public gpu::GpuChannelManagerDelegate,
// The next client id.
int next_client_id_;
- // The main thread message loop.
- base::MessageLoop* main_message_loop_;
+ // The main thread task runner.
+ scoped_refptr<base::SingleThreadTaskRunner> main_task_runner_;
// An event that will be signalled when we shutdown.
base::WaitableEvent shutdown_event_;
« no previous file with comments | « components/mus/common/gpu_service.cc ('k') | components/mus/gpu/gpu_service_mus.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698